"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var KeycloakStrategy_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeycloakStrategy = void 0;
const common_1 = require("@nestjs/common");
const passport_1 = require("@nestjs/passport");
const apollo_server_express_1 = require("apollo-server-express");
const passport_http_bearer_1 = require("passport-http-bearer");
const constants_1 = require("../constants");
const service_1 = require("../service");
let KeycloakStrategy = KeycloakStrategy_1 = class KeycloakStrategy extends passport_1.PassportStrategy(passport_http_bearer_1.Strategy, 'keycloak') {
    constructor(keycloakService) {
        super({ passReqToCallback: true });
        this.keycloakService = keycloakService;
    }
    async validate(req, token) {
        try {
            const type = req.protectionType;
            const realm = this.realmFromToken(token);
            switch (type) {
                case constants_1.PROTECTED:
                    await this.keycloakService.validateAccessToken(realm, token);
                    break;
                case constants_1.HAS_SCOPE:
                    await this.keycloakService.checkScope(realm, req, req.scope, req.resource);
                    break;
                case constants_1.HAS_ROLE:
                    await this.keycloakService.hasRole(realm, token, req.roles);
                    break;
                default:
                    common_1.Logger.warn('No protection type defined denying access', KeycloakStrategy_1.name);
                    if (req.isRest)
                        return false;
                    throw new apollo_server_express_1.ForbiddenError('Invalid server configuration');
            }
            return true;
        }
        catch (error) {
            common_1.Logger.debug(`Invalid token message=${error.message}`, KeycloakStrategy_1.name);
            if (req.isRest)
                return false;
            throw new apollo_server_express_1.ForbiddenError(error.message);
        }
    }
    realmFromToken(token) {
        try {
            const [, payload] = token.split('.');
            const data = JSON.parse(Buffer.from(payload, 'base64').toString());
            return data.iss.substring(data.iss.lastIndexOf('/') + 1);
        }
        catch (error) {
            throw new Error('Invalid token');
        }
    }
};
KeycloakStrategy = KeycloakStrategy_1 = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [service_1.KeycloakService])
], KeycloakStrategy);
exports.KeycloakStrategy = KeycloakStrategy;
//# sourceMappingURL=keycloak.strategy.js.map